@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12213 2020-05-13 14:02:01Z Lavender $
+# $Id: __init__.py 12433 2020-07-29 18:19:03Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-05-13 23:02:01 +0900 (週三, 13 五月 2020) $
-# $Revision: 12213 $
+# $Date: 2020-07-30 03:19:03 +0900 (週四, 30 七月 2020) $
+# $Revision: 12433 $
 
 import os
 import sys
@@ -156,7 +156,7 @@ def attachSettings(settingsDict, enablePaypal=False):
             def get_app_label(app_label, overrides):
                 pattern = app_label.replace('oscar.apps.', '')
                 for override in overrides:
-                    if override.endswith(pattern):
+                    if pattern.startswith(override):
                         if 'dashboard' in override and 'dashboard' not in pattern:
                             continue
                         return override
@@ -234,10 +234,14 @@ def attachSettings(settingsDict, enablePaypal=False):
     ADDING_TEMPLATES_CONTEXT_PROCESSORS = (
         'oscar.apps.search.context_processors.search_form',
         'oscar.apps.checkout.context_processors.checkout',
-        'oscar.apps.customer.notifications.context_processors.notifications',
         'oscar.core.context_processors.metadata',                       
     )
     
+    if not VERSION >= (2, 1):
+        ADDING_TEMPLATES_CONTEXT_PROCESSORS += (
+            'oscar.apps.customer.notifications.context_processors.notifications',
+        )
+    
     if not VERSION >= (2, 0):
         ADDING_TEMPLATES_CONTEXT_PROCESSORS += (
             'oscar.apps.promotions.context_processors.promotions',
@@ -339,6 +343,7 @@ def attachSettings(settingsDict, enablePaypal=False):
     #=========================================================================
     # payment
     defaultSettings = {
+        'CSRF_COOKIE_SAMESITE': None,
         'SESSION_COOKIE_SAMESITE' : None,
     }
 
